@@ -40,12 +40,13 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
                         }
         }
     
+    task["http_request"]["headers"] = {"Content-type": "application/json"}
+    
     if payload is not None:
         if isinstance(payload, dict):
             # Convert dict to JSON string
             payload = json.dumps(payload)
             # specify http content-type to application/json
-            task["http_request"]["headers"] = {"Content-type": "application/json"}
     
         # The API expects a payload of type bytes.
         converted_payload = payload.encode()
@@ -55,6 +56,7 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
         # Add the payload to the request.
         task["http_request"]["body"] = converted_payload
     
+    
     if headers is not None:
         for k,v in headers.items():
             task["http_request"]["headers"][k]=v
@@ -74,7 +76,7 @@ def create_task(task_url, queue_name, payload=None, in_seconds=None, http_method
         # Add the timestamp to the tasks.
         task["schedule_time"] = timestamp    
     
-    logger.debug('task["http_request"]["headers"]=%s', task["http_request"]["headers"])
+    logger.debug('task["http_request"]["headers"]=%s', task["http_request"].get("headers"))
     
     response = client.create_task(request={"parent": parent, "task": task})
     
